History
=======
0.3.1 (2020-10-15)
------------------

- Dependencies were not getting included. Fixed that

0.3.0 (2020-10-15)
------------------

- Fixed a build error

0.2.0 (2020-10-15)
------------------

- Switched documentation to mkdocs
- Removed support for python 3.5
- Fixed a build issue in docs
- Removed dynamic real fom dataset. Was throwing error and was not using it
- Weird Error in build. Included python version in Travis
https://github.com/travis-ci/travis-ci/issues/10056#issuecomment-437667181
- Fixed error with long readme
https://github.com/pypa/warehouse/issues/5890#issuecomment-494868157


0.1.2 (2020-10-13)
------------------

-   Minor changes in documentation.

0.1.0 (2020-10-13)
------------------

-   First release on PyPI.

